@@ -4,6 +4,8 @@
 package PDL::PodParser;
 use PDL::Core '';
 use Pod::Select;
+use File::Spec;
+use File::Basename;
 
 @ISA = qw(Pod::Select);
 
@@ -164,7 +166,7 @@ An implementation of online docs for PDL.
 
 PDL::Doc's main use is in the "help" (synonym "?") and "apropos"
 (synonym "??") commands in the perldl shell.  PDL:Doc provides the
-infrastrucure to index and access PDL's documentation throguh these
+infrastrucure to index and access PDL's documentation through these
 commands.  There is also an API for direct access to the documentation 
 database (see below).
 
@@ -469,7 +471,11 @@ sub ensuredb {
     while (read IN, $plen,2) {
       my ($len) = unpack "S", $plen;
       read IN, $txt, $len;
-      my ($sym, %hash) = split chr(0), $txt;
+      my (@a) =  split chr(0), $txt;
+      push(@a, "") unless(@a % 2);  # Add null string at end if necessary -- solves bug with missing REF section.
+      my ($sym, %hash) = @a;
+     
+      $hash{Dbfile} = $fi; # keep the origin pdldoc.db path
       $this->{SYMS}->{$sym} = {%hash};
     }
     close IN;
@@ -492,6 +498,12 @@ sub savedb {
   binmode OUT;
   while (my ($key,$val) = each %$hash) {
     next if 0 == scalar(%$val);
+    my $fi = $val->{File};
+    if (File::Spec->file_name_is_absolute($fi) && -f $fi) {
+      #store paths to *.pm files relative to pdldoc.db
+      $val->{File} = File::Spec->abs2rel($fi, dirname($this->{Outfile})) ;
+    }
+    delete $val->{Dbfile}; # no need to store Dbfile
     my $txt = "$key".chr(0).join(chr(0),%$val);
     print OUT pack("S",length($txt)).$txt;
   }
@@ -558,7 +570,7 @@ that should be matched against the regex. Valid fields are
   Ref,     # the one-line reference description
   Example, # the example for this function
   Opt,     # options
-  File,    # the path to the source file this docs have been extracted from
+  File,    # the path to the source file these docs have been extracted from
 
 If you wish to have your results sorted by function name, pass a true
 value for C<$sort>.
@@ -660,7 +672,9 @@ sub scan {
 
   my $parser = new PDL::PodParser;
   $parser->{verbose} = $verbose;
-  $parser->parse_from_filehandle($infile,$outfile);
+  eval { $parser->parse_from_filehandle($infile,$outfile) };
+  warn "cannot parse '$file'" if $@;
+
   $this->{SYMS} = {} unless defined $this->{SYMS};
   my $hash = $this->{SYMS};
   my @stats = stat $file;
@@ -684,12 +698,14 @@ sub scan {
   $outfile_text = '';
   $parser = new PDL::PodParser;
   $parser->select('NAME');
-  $parser->parse_from_filehandle($infile,$outfile);
+  eval { $parser->parse_from_filehandle($infile,$outfile) };
+  warn "cannot parse '$file'" if $@;
+
   my @namelines = split("\n",$outfile_text);
   my ($name,$does);
   for (@namelines) {
-     if (/^(PDL) (-) (.*)/ or /\s*(PDL::[\w:]*)\s*(-*)?\s*(.*)\s*$/) {
-       $name = $1; $does = $3;
+     if (/^(PDL) (-) (.*)/ or  /^\s*(Inline::Pdlpp)\s*(-*)?\s*(.*)\s*$/ or /\s*(PDL::[\w:]*)\s*(-*)?\s*(.*)\s*$/) {
+	$name = $1; $does = $3;
      }
      if (/^\s*([a-z][a-z0-9]*) (-+) (.*)/) { # lowercase shell script name
        $name = $1; $does = $3;
@@ -747,7 +763,12 @@ sub funcdocs {
   my ($this,$func,$fout) = @_;
   my $hash = $this->ensuredb;
   barf "unknown function '$func'" unless defined($hash->{$func});
-  funcdocs_fromfile($func,$hash->{$func}->{File},$fout);
+  my $file = $hash->{$func}->{File};
+  my $dbf = $hash->{$func}->{Dbfile};
+  if (!File::Spec->file_name_is_absolute($file) && $dbf) {
+    $file = File::Spec->rel2abs($file, dirname($dbf)); 
+  }
+  funcdocs_fromfile($func,$file,$fout);
 }
 
 =head1 FUNCTIONS
@@ -880,7 +901,7 @@ own code.
  print $pdldoc->gethash->{zeroes}->{Ref};
  
  # See which examples use zeroes
- $pdldoc->search('zeroes', 'Examples', 1);
+ $pdldoc->search('zeroes', 'Example', 1);
  
  # All the functions that use zeroes in their example:
  my @entries = $pdldoc->search('zeroes', 'Example', 1);
@@ -917,7 +938,7 @@ The Ref entry will begin with 'Module:' if it's a module. In code:
 =head1 BUGS
 
 Quite a few shortcomings which will hopefully be fixed following
-discussions on the pdl-porters mailing list.
+discussions on the pdl-devel mailing list.
 
 =head1 AUTHOR
 
